@@ -11,36 +11,28 @@
 
 namespace Monolog\Handler;
 
-use Monolog\Test\TestCase;
+use Aws\DynamoDb\DynamoDbClient;
+use PHPUnit\Framework\MockObject\MockObject;
 
-class DynamoDbHandlerTest extends TestCase
+class DynamoDbHandlerTest extends \Monolog\Test\MonologTestCase
 {
-    private $client;
+    private DynamoDbClient&MockObject $client;
 
-    private $isV3;
+    private bool $isV3;
 
     public function setUp(): void
     {
-        if (!class_exists('Aws\DynamoDb\DynamoDbClient')) {
+        if (!class_exists(DynamoDbClient::class)) {
             $this->markTestSkipped('aws/aws-sdk-php not installed');
         }
 
-        $this->isV3 = defined('Aws\Sdk::VERSION') && version_compare(\Aws\Sdk::VERSION, '3.0', '>=');
+        $this->isV3 = \defined('Aws\Sdk::VERSION') && version_compare(\Aws\Sdk::VERSION, '3.0', '>=');
 
         $implementedMethods = ['__call'];
-        $absentMethods = [];
-        if (method_exists('Aws\DynamoDb\DynamoDbClient', 'formatAttributes')) {
-            $implementedMethods[] = 'formatAttributes';
-        } else {
-            $absentMethods[] = 'formatAttributes';
-        }
 
-        $clientMockBuilder = $this->getMockBuilder('Aws\DynamoDb\DynamoDbClient')
+        $clientMockBuilder = $this->getMockBuilder(DynamoDbClient::class)
             ->onlyMethods($implementedMethods)
             ->disableOriginalConstructor();
-        if ($absentMethods) {
-            $clientMockBuilder->addMethods($absentMethods);
-        }
 
         $this->client = $clientMockBuilder->getMock();
     }
@@ -52,16 +44,6 @@ class DynamoDbHandlerTest extends TestCase
         unset($this->client);
     }
 
-    public function testConstruct()
-    {
-        $this->assertInstanceOf('Monolog\Handler\DynamoDbHandler', new DynamoDbHandler($this->client, 'foo'));
-    }
-
-    public function testInterface()
-    {
-        $this->assertInstanceOf('Monolog\Handler\HandlerInterface', new DynamoDbHandler($this->client, 'foo'));
-    }
-
     public function testGetFormatter()
     {
         $handler = new DynamoDbHandler($this->client, 'foo');
@@ -77,7 +59,7 @@ class DynamoDbHandlerTest extends TestCase
         $handler->setFormatter($formatter);
 
         if ($this->isV3) {
-            $expFormatted = array('foo' => array('N' => 1), 'bar' => array('N' => 2));
+            $expFormatted = ['foo' => ['N' => 1], 'bar' => ['N' => 2]];
         } else {
             $expFormatted = $formatted;
         }
@@ -86,12 +68,7 @@ class DynamoDbHandlerTest extends TestCase
              ->expects($this->once())
              ->method('format')
              ->with($record)
-             ->will($this->returnValue($formatted));
-        $this->client
-             ->expects($this->isV3 ? $this->never() : $this->once())
-             ->method('formatAttributes')
-             ->with($this->isType('array'))
-             ->will($this->returnValue($formatted));
+             ->willReturn($formatted);
         $this->client
              ->expects($this->once())
              ->method('__call')
