@@ -12,12 +12,11 @@
 namespace Monolog\Handler;
 
 use MongoDB\Driver\Manager;
-use Monolog\Test\TestCase;
 
 /**
  * @requires extension mongodb
  */
-class MongoDBHandlerTest extends TestCase
+class MongoDBHandlerTest extends \Monolog\Test\MonologTestCase
 {
     public function testConstructorShouldThrowExceptionForInvalidMongo()
     {
