@@ -12,13 +12,12 @@
 namespace Monolog\Handler;
 
 use Monolog\Level;
-use Monolog\Test\TestCase;
 use PHPUnit\Framework\Attributes\DataProvider;
 
 /**
  * @covers Monolog\Handler\NoopHandler::handle
  */
-class NoopHandlerTest extends TestCase
+class NoopHandlerTest extends \Monolog\Test\MonologTestCase
 {
     #[DataProvider('logLevelsProvider')]
     public function testIsHandling(Level $level)
