@@ -11,13 +11,12 @@
 
 namespace Monolog\Handler;
 
-use Monolog\Test\TestCase;
 use Monolog\Level;
 
 /**
  * @covers Monolog\Handler\NullHandler::handle
  */
-class NullHandlerTest extends TestCase
+class NullHandlerTest extends \Monolog\Test\MonologTestCase
 {
     public function testHandle()
     {
