@@ -11,30 +11,27 @@
 
 namespace Monolog\Handler;
 
-use Monolog\Test\TestCase;
-use Monolog\Logger;
+use Monolog\Level;
 use Monolog\Formatter\LineFormatter;
 use Monolog\Handler\Slack\SlackRecord;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 /**
  * @author Greg Kedzierski <greg@gregkedzierski.com>
  * @see    https://api.slack.com/
  */
-class SlackHandlerTest extends TestCase
+class SlackHandlerTest extends \Monolog\Test\MonologTestCase
 {
     /**
      * @var resource
      */
     private $res;
 
-    /**
-     * @var SlackHandler
-     */
-    private $handler;
+    private SlackHandler $handler;
 
     public function setUp(): void
     {
-        if (!extension_loaded('openssl')) {
+        if (!\extension_loaded('openssl')) {
             $this->markTestSkipped('This test requires openssl to run');
         }
     }
@@ -44,61 +41,60 @@ class SlackHandlerTest extends TestCase
         parent::tearDown();
 
         unset($this->res);
+        unset($this->handler);
     }
 
     public function testWriteHeader()
     {
         $this->createHandler();
-        $this->handler->handle($this->getRecord(Logger::CRITICAL, 'test1'));
+        $this->handler->handle($this->getRecord(Level::Critical, 'test1'));
         fseek($this->res, 0);
         $content = fread($this->res, 1024);
 
-        $this->assertRegexp('{POST /api/chat.postMessage HTTP/1.1\\r\\nHost: slack.com\\r\\nContent-Type: application/x-www-form-urlencoded\\r\\nContent-Length: \d{2,4}\\r\\n\\r\\n}', $content);
+        $this->assertMatchesRegularExpression('{POST /api/chat.postMessage HTTP/1.1\\r\\nHost: slack.com\\r\\nContent-Type: application/x-www-form-urlencoded\\r\\nContent-Length: \d{2,4}\\r\\n\\r\\n}', $content);
     }
 
     public function testWriteContent()
     {
         $this->createHandler();
-        $this->handler->handle($this->getRecord(Logger::CRITICAL, 'test1'));
+        $this->handler->handle($this->getRecord(Level::Critical, 'test1'));
         fseek($this->res, 0);
         $content = fread($this->res, 1024);
 
-        $this->assertRegExp('/username=Monolog/', $content);
-        $this->assertRegExp('/channel=channel1/', $content);
-        $this->assertRegExp('/token=myToken/', $content);
-        $this->assertRegExp('/attachments/', $content);
+        $this->assertMatchesRegularExpression('/username=Monolog/', $content);
+        $this->assertMatchesRegularExpression('/channel=channel1/', $content);
+        $this->assertMatchesRegularExpression('/token=myToken/', $content);
+        $this->assertMatchesRegularExpression('/attachments/', $content);
     }
 
     public function testWriteContentUsesFormatterIfProvided()
     {
         $this->createHandler('myToken', 'channel1', 'Monolog', false);
-        $this->handler->handle($this->getRecord(Logger::CRITICAL, 'test1'));
+        $this->handler->handle($this->getRecord(Level::Critical, 'test1'));
         fseek($this->res, 0);
         $content = fread($this->res, 1024);
 
         $this->createHandler('myToken', 'channel1', 'Monolog', false);
         $this->handler->setFormatter(new LineFormatter('foo--%message%'));
-        $this->handler->handle($this->getRecord(Logger::CRITICAL, 'test2'));
+        $this->handler->handle($this->getRecord(Level::Critical, 'test2'));
         fseek($this->res, 0);
         $content2 = fread($this->res, 1024);
 
-        $this->assertRegexp('/text=test1/', $content);
-        $this->assertRegexp('/text=foo--test2/', $content2);
+        $this->assertMatchesRegularExpression('/text=test1/', $content);
+        $this->assertMatchesRegularExpression('/text=foo--test2/', $content2);
     }
 
     public function testWriteContentWithEmoji()
     {
         $this->createHandler('myToken', 'channel1', 'Monolog', true, 'alien');
-        $this->handler->handle($this->getRecord(Logger::CRITICAL, 'test1'));
+        $this->handler->handle($this->getRecord(Level::Critical, 'test1'));
         fseek($this->res, 0);
         $content = fread($this->res, 1024);
 
-        $this->assertRegexp('/icon_emoji=%3Aalien%3A/', $content);
+        $this->assertMatchesRegularExpression('/icon_emoji=%3Aalien%3A/', $content);
     }
 
-    /**
-     * @dataProvider provideLevelColors
-     */
+    #[DataProvider('provideLevelColors')]
     public function testWriteContentWithColors($level, $expectedColor)
     {
         $this->createHandler();
@@ -106,36 +102,36 @@ class SlackHandlerTest extends TestCase
         fseek($this->res, 0);
         $content = fread($this->res, 1024);
 
-        $this->assertRegexp('/%22color%22%3A%22'.$expectedColor.'/', $content);
+        $this->assertMatchesRegularExpression('/%22color%22%3A%22'.$expectedColor.'/', $content);
     }
 
     public function testWriteContentWithPlainTextMessage()
     {
         $this->createHandler('myToken', 'channel1', 'Monolog', false);
-        $this->handler->handle($this->getRecord(Logger::CRITICAL, 'test1'));
+        $this->handler->handle($this->getRecord(Level::Critical, 'test1'));
         fseek($this->res, 0);
         $content = fread($this->res, 1024);
 
-        $this->assertRegexp('/text=test1/', $content);
+        $this->assertMatchesRegularExpression('/text=test1/', $content);
     }
 
-    public function provideLevelColors()
+    public static function provideLevelColors()
     {
-        return array(
-            array(Logger::DEBUG,    urlencode(SlackRecord::COLOR_DEFAULT)),
-            array(Logger::INFO,     SlackRecord::COLOR_GOOD),
-            array(Logger::NOTICE,   SlackRecord::COLOR_GOOD),
-            array(Logger::WARNING,  SlackRecord::COLOR_WARNING),
-            array(Logger::ERROR,    SlackRecord::COLOR_DANGER),
-            array(Logger::CRITICAL, SlackRecord::COLOR_DANGER),
-            array(Logger::ALERT,    SlackRecord::COLOR_DANGER),
-            array(Logger::EMERGENCY,SlackRecord::COLOR_DANGER),
-        );
+        return [
+            [Level::Debug,    urlencode(SlackRecord::COLOR_DEFAULT)],
+            [Level::Info,     SlackRecord::COLOR_GOOD],
+            [Level::Notice,   SlackRecord::COLOR_GOOD],
+            [Level::Warning,  SlackRecord::COLOR_WARNING],
+            [Level::Error,    SlackRecord::COLOR_DANGER],
+            [Level::Critical, SlackRecord::COLOR_DANGER],
+            [Level::Alert,    SlackRecord::COLOR_DANGER],
+            [Level::Emergency,SlackRecord::COLOR_DANGER],
+        ];
     }
 
     private function createHandler($token = 'myToken', $channel = 'channel1', $username = 'Monolog', $useAttachment = true, $iconEmoji = null, $useShortAttachment = false, $includeExtra = false)
     {
-        $constructorArgs = [$token, $channel, $username, $useAttachment, $iconEmoji, Logger::DEBUG, true, $useShortAttachment, $includeExtra];
+        $constructorArgs = [$token, $channel, $username, $useAttachment, $iconEmoji, Level::Debug, true, $useShortAttachment, $includeExtra];
         $this->res = fopen('php://memory', 'a');
         $this->handler = $this->getMockBuilder('Monolog\Handler\SlackHandler')
             ->setConstructorArgs($constructorArgs)
@@ -143,18 +139,16 @@ class SlackHandlerTest extends TestCase
             ->getMock();
 
         $reflectionProperty = new \ReflectionProperty('Monolog\Handler\SocketHandler', 'connectionString');
-        $reflectionProperty->setAccessible(true);
         $reflectionProperty->setValue($this->handler, 'localhost:1234');
 
         $this->handler->expects($this->any())
             ->method('fsockopen')
-            ->will($this->returnValue($this->res));
+            ->willReturn($this->res);
         $this->handler->expects($this->any())
             ->method('streamSetTimeout')
-            ->will($this->returnValue(true));
+            ->willReturn(true);
         $this->handler->expects($this->any())
-            ->method('closeSocket')
-            ->will($this->returnValue(true));
+            ->method('closeSocket');
 
         $this->handler->setFormatter($this->getIdentityFormatter());
     }
