@@ -12,13 +12,12 @@
 namespace Monolog\Handler;
 
 use Monolog\Level;
-use Monolog\Test\TestCase;
 use PHPUnit\Framework\Attributes\DataProvider;
 
 /**
  * @covers Monolog\Handler\TestHandler
  */
-class TestHandlerTest extends TestCase
+class TestHandlerTest extends \Monolog\Test\MonologTestCase
 {
     #[DataProvider('methodProvider')]
     public function testHandler($method, Level $level)
